<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	
	<xsl:output method="html"/>
    
    <xsl:template match="registration">
        <HTML>
            <HEAD>
                <TITLE>Rule sets <xsl:value-of select="@uri"/></TITLE>
            </HEAD>
            <BODY>
                <H1>Rule set <xsl:value-of select="@uri"/></H1>
                
                <TABLE cellspacing="0" cellpadding="3">
                    <xsl:choose>
                        <xsl:when test="@ref">
                            <TR>
                                <TD><B>Reference</B></TD>
                                <TD><xsl:value-of select="@ref"></xsl:value-of></TD>
                            </TR>
                        </xsl:when>
                        
                        <xsl:otherwise>
                            <TR>
                                <TD><B>Name</B></TD><TD><xsl:value-of select="definition/*/name"></xsl:value-of></TD>                               
                            </TR>
                            
                            <TR>
                                <TD><B>Description</B></TD><TD><xsl:value-of select="definition/*/description"></xsl:value-of></TD>                                
                            </TR>
                            
                            <xsl:if test="definition/*/object-filter">
	                            <TR>
	                            	<TD><B>Default object filter</B></TD>
	                            	<TD><xsl:value-of select="definition/*/object-filter/@type"/></TD>
	                            </TR>
                            </xsl:if>                             
                            	
                        </xsl:otherwise>                                
                    </xsl:choose>
                </TABLE>    
                
     <xsl:if test="properties/entry">
         <H2>Properties</H2>
         
         <table border="1" cellspacing="0" cellpadding="3">
             <tr bgcolor="silver">
                 <th colspan="2">Key</th>
                 <th colspan="2">Value</th>
             </tr>
             
             <tr bgcolor="silver">
                 <th>Value</th>
                 <th>Type</th>
                 <th>Value</th>                                                  
                 <th>Type</th>
             </tr>
             
            <xsl:for-each select="properties">
            <xsl:sort select="key"/>
                <tr>
                    <td><xsl:value-of select="entry/key"></xsl:value-of></td>
                    <td><xsl:value-of select="entry/key/@type"></xsl:value-of></td>
                    <td><xsl:value-of select="entry/value"></xsl:value-of></td>
                    <td><xsl:value-of select="entry/value/@type"></xsl:value-of></td>
                </tr>
            </xsl:for-each>
         </table>
    
    </xsl:if>
                
    <xsl:if test="definition/*/rules/rule">
    
        <H2>Rules</H2>
        
         <table border="1" cellspacing="0" cellpadding="3">
             <tr bgcolor="silver">
                 <th>Name</th>
                 <th>Description</th>
                 <th colspan="3">Properties</th>
             </tr>
                          
            <xsl:for-each select="definition/*/rules/rule">
                <xsl:sort select="name"/>
                
                <xsl:variable name="propCount" select="count(*[not(name()='name') and not(name()='description')])"/>
                <tr>
                    <td rowspan="{$propCount+1}"><xsl:value-of select="name"/></td>
                    <td rowspan="{$propCount+1}"><xsl:value-of select="description"/></td>

                    <xsl:choose>
                        <xsl:when test="*[not(name()='name') and not(name()='description')]">
                            <th bgcolor="silver">Name</th>
                            <th bgcolor="silver">Type</th>
                            <th bgcolor="silver">Value</th>
                        </xsl:when>
                        
                        <xsl:otherwise><td colspan="3"><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text> </td></xsl:otherwise>
                        
                    </xsl:choose>                    
                    
                </tr>
                
                    
                <xsl:for-each select="*[not(name()='name') and not(name()='description')]">
                    <xsl:sort select="name()"/>
                    
                    <tr>
                        <td><xsl:value-of select="name()"/></td>
                        <td><xsl:value-of select="@type"/></td>
                        <td><xsl:value-of select="text()"/></td>
                    </tr>                
                </xsl:for-each>
                
            </xsl:for-each>
         </table>
    </xsl:if>        
                            
            </BODY>            
        </HTML>        
    </xsl:template>
	
</xsl:stylesheet>