/*
 * hammurapi-rules-tck @mesopotamia.version@
 * Hammurapi rules JSR-94 TCK files. 
 * Copyright (C) 2006  Hammurapi Group
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * URL: http://http://www.hammurapi.biz
 * e-Mail: support@hammurapi.biz
 */
package biz.hammurapi.rules.jsr94.tck;

import org.jcp.jsr94.tck.model.Customer;
import org.jcp.jsr94.tck.model.Invoice;

import biz.hammurapi.rules.Rule;

public class TckRule extends Rule {
	
	/**
	 * This method filters invoices so only unpaid ones are passed to <code>infer(customer, invoice)</code>
	 * @param invoice
	 * @param acceptInfo
	 */
	public boolean accept(Invoice invoice, AcceptInfo acceptInfo) {
		return !"paid".equals(invoice.getStatus());
	}

	/**
	 * If the credit limit of the customer is greater than the amount of the invoice 
	 * and the status of the invoice is unpaid then decrement
	 * the credit limit with the amount of invoice and set the status of the
	 * invoice to paid.
	 * @param customer
	 * @param invoice
	 */
	public void infer(Customer customer, Invoice invoice) {
		if (customer.getCreditLimit()>invoice.getAmount()) {
			customer.setCreditLimit(customer.getCreditLimit()-invoice.getAmount());
			invoice.setStatus("paid");
		}
	}
}
